@@ -24,6 +24,10 @@ class BasketForm extends DirectorObjectForm
             'IcingaTemplateChoiceService' => $this->translate('Service Template Choice'),
             'ServiceTemplate'    => $this->translate('Service Templates'),
             'ServiceSet'         => $this->translate('Service Sets'),
+            'UserGroup'          => $this->translate('User Groups'),
+            'UserTemplate'       => $this->translate('User Templates'),
+            'User'               => $this->translate('Users'),
+            'NotificationTemplate' => $this->translate('Notification Templates'),
             'Notification'       => $this->translate('Notifications'),
             'TimePeriod'         => $this->translate('Time Periods'),
             'Dependency'         => $this->translate('Dependencies'),
