@@ -102,6 +102,26 @@ class ImportRowModifierForm extends DirectorObjectForm
         $this->setButtons();
     }
 
+    public function getSetting($name, $default = null)
+    {
+        if ($this->hasBeenSent()) {
+            $value = $this->getSentValue($name);
+            if ($value !== null) {
+                return $value;
+            }
+        }
+        if ($this->isNew()) {
+            $value = $this->getElement($name)->getValue();
+            if ($value === null) {
+                return $default;
+            }
+
+            return $value;
+        }
+
+        return $this->object()->getSetting($name, $default);
+    }
+
     /**
      * @return ImportSourceHook
      * @throws ConfigurationError
@@ -143,10 +163,10 @@ class ImportRowModifierForm extends DirectorObjectForm
 
         if ($class !== null) {
             if (! class_exists($class)) {
-                throw new RuntimeException(
+                throw new RuntimeException(sprintf(
                     'The hooked class "%s" for this property modifier does no longer exist',
                     $class
-                );
+                ));
             }
 
             $class::addSettingsFormFields($this);
