@@ -37,7 +37,7 @@ class CustomVariableString extends CustomVariable
         return $this;
     }
 
-    public function flatten(array & $flat, $prefix)
+    public function flatten(array &$flat, $prefix)
     {
         // TODO: we should get rid of type=string and always use JSON
         $flat[$prefix] = json_encode($this->getValue());
@@ -46,7 +46,7 @@ class CustomVariableString extends CustomVariable
     public function toConfigString($renderExpressions = false)
     {
         if ($renderExpressions) {
-            return c::renderStringWithVariables($this->getValue());
+            return c::renderStringWithVariables($this->getValue(), ['config']);
         } else {
             return c::renderString($this->getValue());
         }
