@@ -5,6 +5,7 @@ namespace Icinga\Module\Director\Db;
 use DirectoryIterator;
 use Exception;
 use Icinga\Application\Icinga;
+use Icinga\Exception\ProgrammingError;
 use Icinga\Module\Director\Data\Db\DbConnection;
 use RuntimeException;
 
@@ -67,6 +68,9 @@ class Migrations
         return count($this->listPendingMigrations());
     }
 
+    /**
+     * @return Migration[]
+     */
     public function getPendingMigrations()
     {
         $migrations = array();
@@ -80,8 +84,14 @@ class Migrations
         return $migrations;
     }
 
+    /**
+     * @return $this
+     */
     public function applyPendingMigrations()
     {
+        // Ensure we have enough time to migrate
+        ini_set('max_execution_time', 0);
+
         foreach ($this->getPendingMigrations() as $migration) {
             $migration->apply($this->connection);
         }
@@ -129,16 +139,31 @@ class Migrations
         if ($version === 0) {
             $filename = $this->getFullSchemaFile();
         } else {
-            $filename = sprintf(
-                '%s/upgrade_%d.sql',
-                $this->getMigrationsDir(),
-                $version
-            );
+            $filename = $this->getMigrationFileName($version);
         }
 
         return file_get_contents($filename);
     }
 
+    public function hasBeenDowngraded()
+    {
+        return ! $this->hasMigrationFile($this->getLastMigrationNumber());
+    }
+
+    public function hasMigrationFile($version)
+    {
+        return \file_exists($this->getMigrationFileName($version));
+    }
+
+    protected function getMigrationFileName($version)
+    {
+        return sprintf(
+            '%s/upgrade_%d.sql',
+            $this->getMigrationsDir(),
+            $version
+        );
+    }
+
     protected function listMigrationsAfter($version)
     {
         $filtered = array();
@@ -171,7 +196,15 @@ class Migrations
 
     protected function getSchemaDir($sub = null)
     {
-        $dir = $this->getModuleDir('/schema');
+        try {
+            $dir = $this->getModuleDir('/schema');
+        } catch (ProgrammingError $e) {
+            throw new RuntimeException(
+                'Unable to detect the schema directory for this module',
+                0,
+                $e
+            );
+        }
         if ($sub === null) {
             return $dir;
         } else {
@@ -179,6 +212,11 @@ class Migrations
         }
     }
 
+    /**
+     * @param string $sub
+     * @return string
+     * @throws ProgrammingError
+     */
     protected function getModuleDir($sub = '')
     {
         return Icinga::app()->getModuleManager()->getModuleDir(
