@@ -63,47 +63,56 @@ abstract class ObjectController extends ActionController
     {
         parent::init();
         $this->enableStaticObjectLoader($this->getTableName());
-
         if ($this->getRequest()->isApiRequest()) {
-            $handler = new IcingaObjectHandler($this->getRequest(), $this->getResponse(), $this->db());
-            try {
-                $this->loadOptionalObject();
-            } catch (NotFoundError $e) {
-                // Silently ignore the error, the handler will complain
-                $handler->sendJsonError($e, 404);
-                // TODO: nice shutdown
-                exit;
-            }
-
-            $handler->setApi($this->api());
-            if ($this->object) {
-                $handler->setObject($this->object);
-            }
-            $handler->dispatch();
-            // Hint: also here, hard exit. There is too much magic going on.
-            // Letting this bubble up smoothly would be "correct", but proved
-            // to be too fragile. Web 2, all kinds of pre/postDispatch magic,
-            // different view renderers - hard exit is the only safe bet right
-            // now.
-            exit;
+            $this->initializeRestApi();
         } else {
+            $this->initializeWebRequest();
+        }
+    }
+
+    protected function initializeRestApi()
+    {
+        $handler = new IcingaObjectHandler($this->getRequest(), $this->getResponse(), $this->db());
+        try {
             $this->loadOptionalObject();
-            if ($this->getRequest()->getActionName() === 'add') {
-                $this->addSingleTab(
-                    sprintf($this->translate('Add %s'), ucfirst($this->getType())),
-                    null,
-                    'add'
-                );
-            } else {
-                $this->tabs(new ObjectTabs(
-                    $this->getRequest()->getControllerName(),
-                    $this->getAuth(),
-                    $this->object
-                ));
-            }
-            if ($this->object !== null) {
-                $this->addDeploymentLink();
-            }
+        } catch (NotFoundError $e) {
+            // Silently ignore the error, the handler will complain
+            $handler->sendJsonError($e, 404);
+            // TODO: nice shutdown
+            exit;
+        }
+
+        $handler->setApi($this->api());
+        if ($this->object) {
+            $handler->setObject($this->object);
+        }
+        $handler->dispatch();
+        // Hint: also here, hard exit. There is too much magic going on.
+        // Letting this bubble up smoothly would be "correct", but proved
+        // to be too fragile. Web 2, all kinds of pre/postDispatch magic,
+        // different view renderers - hard exit is the only safe bet right
+        // now.
+        exit;
+    }
+
+    protected function initializeWebRequest()
+    {
+        $this->loadOptionalObject();
+        if ($this->getRequest()->getActionName() === 'add') {
+            $this->addSingleTab(
+                sprintf($this->translate('Add %s'), ucfirst($this->getType())),
+                null,
+                'add'
+            );
+        } else {
+            $this->tabs(new ObjectTabs(
+                $this->getRequest()->getControllerName(),
+                $this->getAuth(),
+                $this->object
+            ));
+        }
+        if ($this->object !== null) {
+            $this->addDeploymentLink();
         }
     }
 
@@ -131,13 +140,6 @@ abstract class ObjectController extends ActionController
         if ($oType = $this->params->get('type', 'object')) {
             $form->setPreferredObjectType($oType);
         }
-        if ($this->getTableName() === 'icinga_service_set'
-            && $this->showNotInBranch($this->translate('Creating Service Sets'))
-        ) {
-            $this->addTitle($this->translate('Create a new Service Set'));
-            return;
-        }
-
         if ($oType === 'template') {
             if ($this->showNotInBranch($this->translate('Creating Templates'))) {
                 $this->addTitle($this->translate('Create a new Template'));
@@ -148,6 +150,10 @@ abstract class ObjectController extends ActionController
         } else {
             $this->addObject();
         }
+        $branch = $this->getBranch();
+        if ($branch->isBranch() && ! $this->getRequest()->isApiRequest()) {
+            $this->content()->add(new BranchedObjectHint($branch, $this->Auth()));
+        }
 
         $form->handleRequest();
         $this->content()->add($form);
@@ -161,7 +167,11 @@ abstract class ObjectController extends ActionController
         $object = $this->requireObject();
         $this->tabs()->activate('modify');
         $this->addObjectTitle();
-        if ($object->isTemplate() && $this->showNotInBranch($this->translate('Modifying Templates'))) {
+        // Hint: Service Sets are 'templates' (as long as not being assigned to a host
+        if ($this->getTableName() !== 'icinga_service_set'
+            && $object->isTemplate()
+            && $this->showNotInBranch($this->translate('Modifying Templates'))
+        ) {
             return;
         }
         if ($object->isApplyRule() && $this->showNotInBranch($this->translate('Modifying Apply Rules'))) {
