@@ -3,9 +3,10 @@
 namespace Icinga\Module\Director\Web\Table;
 
 use Icinga\Module\Director\Objects\IcingaEndpoint;
-use dipl\Html\Link;
-use dipl\Html\Table;
-use dipl\Translation\TranslationHelper;
+use gipfl\IcingaWeb2\Link;
+use ipl\Html\Html;
+use ipl\Html\Table;
+use gipfl\Translation\TranslationHelper;
 
 class CoreApiObjectsTable extends Table
 {
@@ -32,10 +33,12 @@ class CoreApiObjectsTable extends Table
 
     public function assemble()
     {
-        $this->header();
-        $body = $this->body();
+        if (empty($this->objects)) {
+            return;
+        }
+        $this->add(Html::tag('thead', Html::tag('tr', Html::wrapEach($this->getColumnsToBeRendered(), 'th'))));
         foreach ($this->objects as $name) {
-            $body->add($this::tr($this::td(Link::create(
+            $this->add($this::tr($this::td(Link::create(
                 str_replace('!', ': ', $name),
                 'director/inspect/object',
                 [
