@@ -2,8 +2,8 @@
 
 namespace Icinga\Module\Director\Web\Table;
 
-use dipl\Html\Link;
-use dipl\Web\Table\ZfQueryBasedTable;
+use gipfl\IcingaWeb2\Link;
+use gipfl\IcingaWeb2\Table\ZfQueryBasedTable;
 use Icinga\Date\DateFormatter;
 
 class DeploymentLogTable extends ZfQueryBasedTable
@@ -30,7 +30,7 @@ class DeploymentLogTable extends ZfQueryBasedTable
         $shortSum = $this->getShortChecksum($row->config_checksum);
         $tr = $this::tr([
             $this::td(Link::create(
-                [$row->peer_identity, " ($shortSum)"],
+                $shortSum === null ? $row->peer_identity : [$row->peer_identity, " ($shortSum)"],
                 'director/deployment',
                 ['id' => $row->id]
             )),
