@@ -3,6 +3,7 @@
 namespace Icinga\Module\Director\Web\Widget;
 
 use gipfl\Json\JsonString;
+use Icinga\Module\Director\Objects\DirectorActivityLog;
 use ipl\Html\HtmlDocument;
 use ipl\Html\HtmlElement;
 use Icinga\Date\DateFormatter;
@@ -343,7 +344,6 @@ class ActivityLogInfo extends HtmlDocument
     /**
      * @param Url|null $url
      * @return Tabs
-     * @throws ProgrammingError
      */
     public function getTabs(Url $url = null)
     {
@@ -357,13 +357,12 @@ class ActivityLogInfo extends HtmlDocument
     /**
      * @param Url $url
      * @return Tabs
-     * @throws ProgrammingError
      */
     public function createTabs(Url $url)
     {
         $entry = $this->entry;
         $tabs = new Tabs();
-        if ($entry->action_name === 'modify') {
+        if ($entry->action_name === DirectorActivityLog::ACTION_MODIFY) {
             $tabs->add('diff', [
                 'label' => $this->translate('Diff'),
                 'url'   => $url->without('show')->with('id', $entry->id)
@@ -372,7 +371,10 @@ class ActivityLogInfo extends HtmlDocument
             $this->defaultTab = 'diff';
         }
 
-        if (in_array($entry->action_name, ['create', 'modify'])) {
+        if (in_array($entry->action_name, [
+            DirectorActivityLog::ACTION_CREATE,
+            DirectorActivityLog::ACTION_MODIFY,
+        ])) {
             $tabs->add('new', [
                 'label' => $this->translate('New object'),
                 'url'   => $url->with(['id' => $entry->id, 'show' => 'new'])
@@ -383,7 +385,10 @@ class ActivityLogInfo extends HtmlDocument
             }
         }
 
-        if (in_array($entry->action_name, ['delete', 'modify'])) {
+        if (in_array($entry->action_name, [
+            DirectorActivityLog::ACTION_DELETE,
+            DirectorActivityLog::ACTION_MODIFY,
+        ])) {
             $tabs->add('old', [
                 'label' => $this->translate('Former object'),
                 'url'   => $url->with(['id' => $entry->id, 'show' => 'old'])
@@ -572,13 +577,13 @@ class ActivityLogInfo extends HtmlDocument
     public function getTitle()
     {
         switch ($this->entry->action_name) {
-            case 'create':
+            case DirectorActivityLog::ACTION_CREATE:
                 $msg = $this->translate('%s "%s" has been created');
                 break;
-            case 'delete':
+            case DirectorActivityLog::ACTION_DELETE:
                 $msg = $this->translate('%s "%s" has been deleted');
                 break;
-            case 'modify':
+            case DirectorActivityLog::ACTION_MODIFY:
                 $msg = $this->translate('%s "%s" has been modified');
                 break;
             default:
