@@ -27,7 +27,7 @@ class IcingaServiceTest extends BaseTestCase
     }
 
     /**
-     * @expectedException \Icinga\Exception\NotFoundError
+     * @expectedException \RuntimeException
      */
     public function testFailsToStoreWithMissingLazyRelations()
     {
@@ -51,7 +51,7 @@ class IcingaServiceTest extends BaseTestCase
     }
 
     /**
-     * @expectedException Icinga\Exception\ProgrammingError
+     * @expectedException \LogicException
      */
     public function testRefusesAssignRulesWhenNotBeingAnApply()
     {
@@ -185,8 +185,12 @@ class IcingaServiceTest extends BaseTestCase
 
         $db = $this->getDb();
 
+        $host = $this->host();
+        $host->store($db);
+
         $service = $this->service('___TEST___service_$not_replaced$');
         $service->object_type = 'object';
+        $service->host_id = $host->get('id');
         $service->display_name = 'Service: $host.vars.not_replaced$';
         $service->{'vars.custom_var'} = '$host.vars.not_replaced$';
         $service->store($db);
